# Changelog

## [0.3.5a1](https://github.com/OpenVoiceOS/ovos-core/tree/0.3.5a1) (2024-12-10)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/0.3.4...0.3.5a1)

**Merged pull requests:**

- optimize: dont load padacioso if not needed by default [\#629](https://github.com/OpenVoiceOS/ovos-core/pull/629) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
